==> haskell-text-builder-0.6.7-275.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder
version:              0.6.7
visibility:           public
id:                   text-builder-0.6.7-LAkGrXYuG8fAiN6moYHMtp
key:                  text-builder-0.6.7-LAkGrXYuG8fAiN6moYHMtp
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  21ceda0c0fa1476d8933bf97b2d5d6db
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-builder-0.6.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-builder-0.6.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-builder-0.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder
hs-libraries:         HStext-builder-0.6.7-LAkGrXYuG8fAiN6moYHMtp
depends:
    base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
    text-builder-dev-0.3.3.2-KtXsOcYvoZwLb682mlM259

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-0.6.7-276-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder
version:              0.6.7
visibility:           public
id:                   text-builder-0.6.7-2GbfFq7sbMXC2rkto55lVx
key:                  text-builder-0.6.7-2GbfFq7sbMXC2rkto55lVx
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  f331b2fe69968ff5e44d38eccf652392
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-builder-0.6.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-builder-0.6.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-builder-0.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder
hs-libraries:         HStext-builder-0.6.7-2GbfFq7sbMXC2rkto55lVx
depends:
    base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
    text-builder-dev-0.3.3.2-L58l8PPDN2E4ITBQArlBLY

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
